local _
local _G = _G
local addonName, LFGShout = ...
local VERSION = GetAddOnMetadata(addonName, "Version")

-- =============================================================================================================

local LFGShoutFrame = CreateFrame("Frame", "LFGShoutFrame", UIParent)

-- =============================================================================================================

local DUNGEON_LIST = {
	{ Name = "Ragefire Chasm",		Code = "RFC",					Level = "13 - 18" },
	{ Name = "Wailing Caverns",		Code = "WC",					Level = "15 - 25" },
	{ Name = "The Deadmines",			Code = "Dead Mines",	Level = "18 - 23" },
	{ Name = "Shadowfang Keep",		Code = "SFK",					Level = "22 - 30" },
	{ Name = "Blackfathom Deeps", Code = "BFD",					Level = "20 - 30" },
	{ Name = "The Stockade",			Code = "Stockade",		Level = "22 - 30" },
	{ Name = "Gnomeregan",				Code = "Gnomeregan",	Level = "24 - 34" },
	{ Name = "Razorfen Kraul",		Code = "RFK",					Level = "30 - 40" },
	{ Name = "SM - Graveyard",		Code = "SM GY",				Level = "26 - 36" },
	{ Name = "SM - Library",			Code = "SM Lib",			Level = "29 - 39" },
	{ Name = "SM - Armory",				Code = "SM Armory",		Level = "32 - 42" },
	{ Name = "SM - Cathedral",		Code = "SM Cath",			Level = "35 - 45" },
	{ Name = "Razorfen Downs",		Code = "RFD",					Level = "40 - 50" },
	{ Name = "Uldaman",						Code = "ULDA",				Level = "35 - 45" },
	{ Name = "Zul'Farrak",				Code = "ZF",					Level = "44 - 54" },
	{ Name = "Maraudon",					Code = "MARA",				Level = "46 - 55" },
	{ Name = "Sunken Temple",			Code = "ST",					Level = "55 - 60" },
	{ Name = "Blackrock Depths",	Code = "BRD",					Level = "52 - 60" },
	{ Name = "Blackrock Spire L", Code = "LBRS",				Level = "55 - 60" },
	{ Name = "Blackrock Spire U", Code = "UBRS",				Level = "55 - 60" },
	{ Name = "Dire Maul",					Code = "DM",					Level = "55 - 60" },
	{ Name = "Scholomance",				Code = "Scholo",			Level = "58 - 60" },
	{ Name = "Stratholme",				Code = "Strat",				Level = "58 - 60" },
}

local DUNGEON_BUTTONS = { }
local GENERAL_CHANNEL, TRADE_CHANNEL, LFG_CHANNEL = 0, 0, 0
local LEFT_BUTTON, RIGHT_BUTTON, MIDDLE_BUTTON = "LeftButton", "RightButton", "MiddleButton"

-- =============================================================================================================
	
local function LFGShout_SaveSettings()
	LFGShout_Settings.StartText = LFGShoutFrame.OptionsFrame.StartText:GetText()
	LFGShout_Settings.EndText = LFGShoutFrame.OptionsFrame.EndText:GetText()
	LFGShout_Settings.ChannelGeneral = LFGShoutFrame.OptionsFrame.ChannelGeneral:GetChecked()
	LFGShout_Settings.ChannelTrade = LFGShoutFrame.OptionsFrame.ChannelTrade:GetChecked()
	LFGShout_Settings.ChannelLFG = LFGShoutFrame.OptionsFrame.ChannelLFG:GetChecked()
	LFGShout_Settings.ChannelGuild = LFGShoutFrame.OptionsFrame.ChannelGuild:GetChecked()
	wipe(LFGShout_Settings.CheckedDungeons)
	for i, child in pairs(DUNGEON_BUTTONS) do
		if child:GetChecked() then
			tinsert(LFGShout_Settings.CheckedDungeons, child:GetID())
		end
	end
	--print("LFGShout_Settings: SAVE")
end

-- =============================================================================================================

local function LFGShout_Shout(button)
	local text = format("<%s>  ", LFGShoutFrame.OptionsFrame.StartText:GetText())
	for i, child in pairs(DUNGEON_BUTTONS) do
		if child:GetChecked() then 
			text = format("%s%s / ", text, DUNGEON_LIST[child:GetID()].Code)
		end
	end
	text = format("%s  %s", strtrim(text, " / "), LFGShoutFrame.OptionsFrame.EndText:GetText())

	if IsModifierKeyDown() then --if button == LEFT_BUTTON then
		print("|c00FF5C1ALFGShout: |r" .. text)
	else
		if LFGShoutFrame.OptionsFrame.ChannelGuild:GetChecked() then
			SendChatMessage(text, "GUILD")
		end
		
		if LFGShoutFrame.OptionsFrame.ChannelLFG:GetChecked() then
			C_Timer.After(0.1, function() SendChatMessage(text, "CHANNEL", nil, LFG_CHANNEL) end)
		end

		if LFGShoutFrame.OptionsFrame.ChannelGeneral:GetChecked() then
			C_Timer.After(0.5, function() SendChatMessage(text, "CHANNEL", nil, GENERAL_CHANNEL) end)
		end
		
		if LFGShoutFrame.OptionsFrame.ChannelTrade:GetChecked() then
			C_Timer.After(0.9, function() SendChatMessage(text, "CHANNEL", nil, TRADE_CHANNEL) end)
		end
	end
end

-- =============================================================================================================

local function LFGShout_RefreshChannels()
	GENERAL_CHANNEL = GetChannelName("General - " .. tostring(GetRealZoneText()))
	TRADE_CHANNEL = GetChannelName("Trade - City")
	LFG_CHANNEL = GetChannelName("LookingForGroup")
--	LFGShoutFrame.OptionsFrame.ChannelGeneral.Text:SetText("General: " .. GENERAL_CHANNEL)
--	LFGShoutFrame.OptionsFrame.ChannelTrade.Text:SetText("Trade: " .. TRADE_CHANNEL)
--	LFGShoutFrame.OptionsFrame.ChannelLFG.Text:SetText("LookingForGroup: " .. LFG_CHANNEL)
	LFGShoutFrame.OptionsFrame.ChannelGeneral.Text:SetFormattedText("|c00FF5C1A%d|r General", GENERAL_CHANNEL)
	LFGShoutFrame.OptionsFrame.ChannelTrade.Text:SetFormattedText("|c00FF5C1A%d|r Trade", TRADE_CHANNEL)
	LFGShoutFrame.OptionsFrame.ChannelLFG.Text:SetFormattedText("|c00FF5C1A%d|r LookingForGroup", LFG_CHANNEL)
	--print("|c00FF5C1ALFGShout: |rRefreshing Channels.")
end

-- =============================================================================================================

--local function LFGShout_Minimize(self)
----	self:SetHeight(self:GetHeight() < 30 and MAX_HEIGHT or MIN_HEIGHT)
--	self:SetHeight(MIN_HEIGHT)
--	for i, child in pairs(DUNGEON_BUTTONS) do
--		child:SetShown(false)
--	end
----	self.OptionsFrame:SetShown(false)
--end

-- =============================================================================================================

--local function LFGShout_Maximize(self)
--	self:SetHeight(MAX_HEIGHT)
--	for i, child in pairs(DUNGEON_BUTTONS) do
--		child:SetShown(true)
--	end
--end

-- =============================================================================================================

local function LFGShout_Load()

	if LFGShout_Settings == nil then
		LFGShout_Settings = { }
		LFGShout_Settings.CheckedDungeons = { }
	end

	local MIN_HEIGHT, MAX_HEIGHT = 22, 440

	-- Main Frame ------------------------------------------------------------------------
	if not LFGShoutFrame:IsUserPlaced() then LFGShoutFrame:SetPoint("CENTER") end

	LFGShoutFrame:SetMovable(true)
	LFGShoutFrame:EnableMouse(true)
	LFGShoutFrame:SetClampedToScreen(true)
	LFGShoutFrame:SetSize(145, MAX_HEIGHT)
	LFGShoutFrame:RegisterForDrag(LEFT_BUTTON)
	LFGShoutFrame:SetBackdrop({
		bgFile="Interface/RaidFrame/UI-RaidFrame-GroupBg",
		edgeFile="Interface/Tooltips/UI-Tooltip-Border", 
		tile = false, tileSize = 0, edgeSize = 10,
		insets = { left = 2, right = 2, top = 2, bottom = 2 }
	})
	LFGShoutFrame:SetBackdropColor(0, 0, 0, 0.7)
	LFGShoutFrame:SetBackdropBorderColor(0.1, 0.1, 0.1)
	LFGShoutFrame:SetScript("OnDragStart", function(self, button) self:StartMoving() end)
	LFGShoutFrame:SetScript("OnDragStop", function(self) self:StopMovingOrSizing() end)

--	LFGShoutFrame:SetScript("OnEnter",function(self) LFGShout_Maximize(self) end)
--	LFGShoutFrame:SetScript("OnLeave", function(self, motion) self:SetHeight(MIN_HEIGHT) end)
--	LFGShoutFrame:SetScript("OnLeave", function(self) C_Timer.After(1, function() LFGShout_Minimize(self) end) end)

	LFGShoutFrame:SetScript("OnMouseUp", 
		function(self, button, down)
			PlaySound(SOUNDKIT.IG_MAINMENU_OPTION_CHECKBOX_ON)
			if button == RIGHT_BUTTON then
				self:SetHeight(self:GetHeight() < 30 and MAX_HEIGHT or MIN_HEIGHT)
				for i, child in pairs(DUNGEON_BUTTONS) do
					child:SetShown(not child:IsShown())
				end
				LFGShoutFrame.OptionsFrame:SetShown(false)
			end
			if button == MIDDLE_BUTTON then
				LFGShoutFrame.Icon:SetShown(not LFGShoutFrame.Icon:IsShown())
			end
		end
	)

	-- Title
	LFGShoutFrame.Title = LFGShoutFrame:CreateFontString(nil, "OVERLAY", "GameFontNormal")
	LFGShoutFrame.Title:SetPoint("TOP", 0, -5)
	LFGShoutFrame.Title:SetText(addonName)

	-- Icon on top
	LFGShoutFrame.Icon = LFGShoutFrame:CreateTexture(nil, "ARTWORK")
--	LFGShoutFrame.Icon:SetTexture("Interface/WORLDSTATEFRAME/OrcHead.blp")
--	LFGShoutFrame.Icon:SetPoint("TOP", 0, 26)

	SetPortraitTexture(LFGShoutFrame.Icon, "player")
	LFGShoutFrame.Icon:SetPoint("TOP", 0, 110)
	LFGShoutFrame.Icon:SetScale(0.2)
--	LFGShoutFrame.Icon:SetSize(30, 30)


--	LFGShoutFrame.Icon = LFGShoutFrame:CreateTexture(nil, "BACKGROUND")
----	LFGShoutFrame.Icon:SetTexture("Interface/ENCOUNTERJOURNAL/UI-EJ-BOSS-Glazer.blp")
--	LFGShoutFrame.Icon:SetTexture("Interface/ENCOUNTERJOURNAL/UI-EJ-BOSS-Muru.blp")
----	LFGShoutFrame.Icon:SetTexture("Interface/ENCOUNTERJOURNAL/UI-EJ-BOSS-Occularus.blp")
----	LFGShoutFrame.Icon:SetTexture("Interface/ENCOUNTERJOURNAL/UI-EJ-BOSS-Captain Cookie.blp")
----	LFGShoutFrame.Icon:SetTexture("Interface/ENCOUNTERJOURNAL/XXXXXXXXXXXX.blp")
----	LFGShoutFrame.Icon:SetSize(40, 40)
--	LFGShoutFrame.Icon:SetPoint("TOP", 0, 61)

	-- Shout Button
	LFGShoutFrame.ShoutButton = CreateFrame("Button", nil, LFGShoutFrame)--, "UIMenuButtonStretchTemplate")
	LFGShoutFrame.ShoutButton:SetPoint("TOPLEFT", 2, 0)
	LFGShoutFrame.ShoutButton:SetSize(20, 20)
	LFGShoutFrame.ShoutButton:SetNormalTexture("Interface/Buttons/UI-GuildButton-MOTD-Disabled.blp")
	LFGShoutFrame.ShoutButton:SetHighlightTexture("Interface/Buttons/UI-GuildButton-MOTD-Up.blp")

	LFGShoutFrame.ShoutButton:SetScript("OnMouseDown", 
		function(self, button, down)
			--self:GetHighlightTexture():SetPoint("TOPLEFT", 2, -2)
			self:SetPoint("TOPLEFT", 4, -1)
			self:SetScale(0.85)
		end
	)

	LFGShoutFrame.ShoutButton:SetScript("OnMouseUp", 
		function(self, button)
			--self:GetHighlightTexture():SetPoint("TOPLEFT", 0, 0)
			self:SetPoint("TOPLEFT", 2, 0)
			self:SetScale(1)
			LFGShout_Shout(button)
			PlaySound(SOUNDKIT.IG_MAINMENU_OPTION_CHECKBOX_ON)
		end
	)

	-- Options Button
	LFGShoutFrame.OptionsButton = CreateFrame("Button", nil, LFGShoutFrame)--, "UIMenuButtonStretchTemplate")
	LFGShoutFrame.OptionsButton:SetPoint("TOPRIGHT", 0, 0)
	LFGShoutFrame.OptionsButton:SetSize(20, 20)
	LFGShoutFrame.OptionsButton:SetNormalTexture("Interface/GossipFrame/HealerGossipIcon.blp")
	LFGShoutFrame.OptionsButton:SetHighlightTexture("Interface/Buttons/UI-OptionsButton.blp")
--	LFGShoutFrame.OptionsButton:SetHighlightTexture("Interface/Buttons/AdventureGuideMicrobuttonAlert.blp")

	LFGShoutFrame.OptionsButton:SetScript("OnMouseDown", 
		function(self, button, down)
			--self:GetHighlightTexture():SetPoint("TOPRIGHT", 2, -2)
			self:SetPoint("TOPRIGHT", -2, -1)
			self:SetScale(0.85)
		end
	)

	LFGShoutFrame.OptionsButton:SetScript("OnMouseUp", 
		function(self, button)
			--self:GetHighlightTexture():SetPoint("TOPRIGHT", 0, 0)
			self:SetPoint("TOPRIGHT", 0, 0)
			self:SetScale(1)
			LFGShoutFrame.OptionsFrame:SetShown(not LFGShoutFrame.OptionsFrame:IsShown())
			PlaySound(SOUNDKIT.IG_MAINMENU_OPTION_CHECKBOX_ON)
		end
	)

	-- Check Buttons
	local button
	for i, info in pairs(DUNGEON_LIST) do
		button = CreateFrame("CheckButton", nil, LFGShoutFrame, "InterfaceOptionsCheckButtonTemplate")
		button:SetPoint("TOPLEFT", 3, (button:GetHeight()-18 * i) - 25)
		button:SetHitRectInsets(0, -110, 1, 5)
		button:SetFrameStrata("MEDIUM")
		--button.Text:SetTextColor(1, 0.82, 0)
--		button.Text:SetText(format("%s |c00999999(%s)|r", info.Name, info.Level))
		button.Text:SetText(info.Name)
		button:SetID(i)
		button:SetChecked(tContains(LFGShout_Settings.CheckedDungeons, button:GetID()))
		button:SetScript("OnEnter", 
			function(self, motion)
				self.Text:SetTextColor(1.00, 0.35, 0.00)
				local point, _, _, x = LFGShoutFrame:GetPoint()
				if string.find(point, "LEFT") and x < 205 then
					GameTooltip:SetOwner(self, "ANCHOR_NONE")
					GameTooltip:SetPoint("LEFT", self, "RIGHT", 110, 0)
				else
					GameTooltip:SetOwner(self, nil, -5, -30)
				end
				GameTooltip:SetText(info.Name)
				GameTooltipTextRight1:SetText(self:GetID())
				GameTooltipTextRight1:SetTextColor(1, 1, 1, 0.1)
				GameTooltipTextRight1:Show()
				GameTooltip:AddDoubleLine(info.Code, info.Level, 1, 1, 1, 1, 1, 1)
				--GameTooltip:AddDoubleLine("ID", self:GetID(), 0.2, 0.2, 0.2, 0.2, 0.2, 0.2)
				GameTooltip:Show()
			end
		)
		button:SetScript("OnLeave", function(self, motion) self.Text:SetTextColor(1, 1, 1) GameTooltip:Hide() end)
		button:SetScript("OnClick", function(self, button) LFGShout_SaveSettings() PlaySound(SOUNDKIT.IG_MAINMENU_OPTION_CHECKBOX_ON) end)
		tinsert(DUNGEON_BUTTONS, button)
	end
	-----------------------------------------------------------------------------------------



	-- Options Frame ------------------------------------------------------------------------
	LFGShoutFrame.OptionsFrame = CreateFrame("Frame", nil, LFGShoutFrame)
	LFGShoutFrame.OptionsFrame:SetSize(145, 150)
--	LFGShoutFrame.OptionsFrame:SetPoint("TOPLEFT", LFGShoutFrame, "TOPRIGHT", 0, 0)
	LFGShoutFrame.OptionsFrame:SetPoint("TOPLEFT", LFGShoutFrame, "BOTTOMLEFT", 0, 0)
	LFGShoutFrame.OptionsFrame:SetBackdrop({
		bgFile="Interface/RaidFrame/UI-RaidFrame-GroupBg",
		edgeFile="Interface/Tooltips/UI-Tooltip-Border", 
		tile = false, tileSize = 0, edgeSize = 10,
		insets = { left = 2, right = 2, top = 2, bottom = 2 }
	})
	LFGShoutFrame.OptionsFrame:SetBackdropColor(0, 0, 0, 0.7)
	LFGShoutFrame.OptionsFrame:SetBackdropBorderColor(0.1, 0.1, 0.1)
	LFGShoutFrame.OptionsFrame:Hide()

	-- General Channel (1) Checkbutton
	LFGShoutFrame.OptionsFrame.ChannelGeneral = CreateFrame("CheckButton", nil, LFGShoutFrame.OptionsFrame, "InterfaceOptionsCheckButtonTemplate")
	LFGShoutFrame.OptionsFrame.ChannelGeneral.Text:SetTextColor(1, 0.82, 0)
--	LFGShoutFrame.OptionsFrame.ChannelGeneral.Text:SetText("General Channel: " .. GENERAL_CHANNEL)
	LFGShoutFrame.OptionsFrame.ChannelGeneral:SetPoint("TOPLEFT", 0, 0)
	LFGShoutFrame.OptionsFrame.ChannelGeneral:SetHitRectInsets(0, -110, 1, 5)
	LFGShoutFrame.OptionsFrame.ChannelGeneral:SetChecked(LFGShout_Settings.ChannelGeneral or false)
	LFGShoutFrame.OptionsFrame.ChannelGeneral:SetScript("OnClick", function(self, button) LFGShout_SaveSettings() PlaySound(SOUNDKIT.IG_MAINMENU_OPTION_CHECKBOX_ON) end)
	
	-- Trade Channel (2) Checkbutton
	LFGShoutFrame.OptionsFrame.ChannelTrade = CreateFrame("CheckButton", nil, LFGShoutFrame.OptionsFrame, "InterfaceOptionsCheckButtonTemplate")
	LFGShoutFrame.OptionsFrame.ChannelTrade.Text:SetTextColor(1, 0.82, 0)
--	LFGShoutFrame.OptionsFrame.ChannelTrade.Text:SetText("Trade Channel: " .. TRADE_CHANNEL)
	LFGShoutFrame.OptionsFrame.ChannelTrade:SetPoint("TOPLEFT", 0, -18)
	LFGShoutFrame.OptionsFrame.ChannelTrade:SetHitRectInsets(0, -100, 1, 5)
	LFGShoutFrame.OptionsFrame.ChannelTrade:SetChecked(LFGShout_Settings.ChannelTrade or false)
	LFGShoutFrame.OptionsFrame.ChannelTrade:SetScript("OnClick", function(self, button) LFGShout_SaveSettings() PlaySound(SOUNDKIT.IG_MAINMENU_OPTION_CHECKBOX_ON) end)

	-- LFG Channel (4) Checkbutton
	LFGShoutFrame.OptionsFrame.ChannelLFG = CreateFrame("CheckButton", nil, LFGShoutFrame.OptionsFrame, "InterfaceOptionsCheckButtonTemplate")
	LFGShoutFrame.OptionsFrame.ChannelLFG.Text:SetTextColor(1, 0.82, 0)
--	LFGShoutFrame.OptionsFrame.ChannelLFG.Text:SetText("LFG Channel: " .. LFG_CHANNEL)
	LFGShoutFrame.OptionsFrame.ChannelLFG:SetPoint("TOPLEFT", 0, -36)
	LFGShoutFrame.OptionsFrame.ChannelLFG:SetHitRectInsets(0, -90, 1, 5)
	LFGShoutFrame.OptionsFrame.ChannelLFG:SetChecked(LFGShout_Settings.ChannelLFG or false)
	LFGShoutFrame.OptionsFrame.ChannelLFG:SetScript("OnClick", function(self, button) LFGShout_SaveSettings() PlaySound(SOUNDKIT.IG_MAINMENU_OPTION_CHECKBOX_ON) end)

	-- Guild Checkbutton
	LFGShoutFrame.OptionsFrame.ChannelGuild = CreateFrame("CheckButton", nil, LFGShoutFrame.OptionsFrame, "InterfaceOptionsCheckButtonTemplate")
	LFGShoutFrame.OptionsFrame.ChannelGuild.Text:SetTextColor(1, 0.82, 0)
	LFGShoutFrame.OptionsFrame.ChannelGuild.Text:SetText("Guild Chat")
	LFGShoutFrame.OptionsFrame.ChannelGuild:SetPoint("TOPLEFT", 0, -54)
	LFGShoutFrame.OptionsFrame.ChannelGuild:SetHitRectInsets(0, -70, 1, 5)
	LFGShoutFrame.OptionsFrame.ChannelGuild:SetChecked(LFGShout_Settings.ChannelGuild or false)
	LFGShoutFrame.OptionsFrame.ChannelGuild:SetScript("OnClick", function(self, button) LFGShout_SaveSettings() PlaySound(SOUNDKIT.IG_MAINMENU_OPTION_CHECKBOX_ON) end)

	-- Textbox BEFORE
	LFGShoutFrame.OptionsFrame.StartText = CreateFrame("EditBox", nil, LFGShoutFrame.OptionsFrame)
	LFGShoutFrame.OptionsFrame.StartText:SetPoint("TOPLEFT", 3, -90)
	LFGShoutFrame.OptionsFrame.StartText:SetSize(139, 20)
	LFGShoutFrame.OptionsFrame.StartText:SetFontObject(GameFontWhite)
	LFGShoutFrame.OptionsFrame.StartText:SetTextInsets(4, 0, 0, 0) 
	LFGShoutFrame.OptionsFrame.StartText:SetBackdrop({
		bgFile="Interface/RaidFrame/UI-RaidFrame-GroupBg",
		edgeFile="Interface/Tooltips/UI-Tooltip-Border", 
		tile = false, tileSize = 0, edgeSize = 8,
		insets = { left = 2, right = 2, top = 2, bottom = 2 }
	})
	LFGShoutFrame.OptionsFrame.StartText:SetBackdropBorderColor(0.91, 0.91, 0.1, 0.5)
	LFGShoutFrame.OptionsFrame.StartText:SetText(LFGShout_Settings.StartText or "LFG")
	LFGShoutFrame.OptionsFrame.StartText:SetAutoFocus(false)

	LFGShoutFrame.OptionsFrame.StartText:SetScript("OnEscapePressed", function(self) self:ClearFocus() end)
	LFGShoutFrame.OptionsFrame.StartText:SetScript("OnTextChanged", LFGShout_SaveSettings)

	LFGShoutFrame.OptionsFrame.StartText.Label = LFGShoutFrame.OptionsFrame.StartText:CreateFontString(nil, "ARTWORK", "GameFontNormalSmall")
	LFGShoutFrame.OptionsFrame.StartText.Label:SetPoint("BOTTOMLEFT", LFGShoutFrame.OptionsFrame.StartText, "TOPLEFT", 2, 0)
	LFGShoutFrame.OptionsFrame.StartText.Label:SetText("Start Text")

	-- Textbox AFTER
	LFGShoutFrame.OptionsFrame.EndText = CreateFrame("EditBox", nil, LFGShoutFrame.OptionsFrame)
	LFGShoutFrame.OptionsFrame.EndText:SetPoint("TOPLEFT", 3, -125)
	LFGShoutFrame.OptionsFrame.EndText:SetSize(139, 20)
	LFGShoutFrame.OptionsFrame.EndText:SetFontObject(GameFontWhite)
	LFGShoutFrame.OptionsFrame.EndText:SetTextInsets(4, 0, 0, 0) 
	LFGShoutFrame.OptionsFrame.EndText:SetBackdrop({
		bgFile="Interface/RaidFrame/UI-RaidFrame-GroupBg",
		edgeFile="Interface/Tooltips/UI-Tooltip-Border", 
		tile = false, tileSize = 0, edgeSize = 8,
		insets = { left = 2, right = 2, top = 2, bottom = 2 }
	})
	LFGShoutFrame.OptionsFrame.EndText:SetBackdropBorderColor(0.91, 0.91, 0.1, 0.5)
	LFGShoutFrame.OptionsFrame.EndText:SetText(LFGShout_Settings.EndText or "")
	LFGShoutFrame.OptionsFrame.EndText:SetAutoFocus(false)

	LFGShoutFrame.OptionsFrame.EndText:SetScript("OnEscapePressed", function(self) self:ClearFocus() end)
	LFGShoutFrame.OptionsFrame.EndText:SetScript("OnTextChanged", LFGShout_SaveSettings)


	LFGShoutFrame.OptionsFrame.EndText.Label = LFGShoutFrame.OptionsFrame.EndText:CreateFontString(nil, "ARTWORK", "GameFontNormalSmall")
	LFGShoutFrame.OptionsFrame.EndText.Label:SetPoint("BOTTOMLEFT", LFGShoutFrame.OptionsFrame.EndText, "TOPLEFT", 2, 0)
	LFGShoutFrame.OptionsFrame.EndText.Label:SetText("End Text")
	-----------------------------------------------------------------------------------------

	LFGShoutFrame:SetScale(1.1)
	
end

-- =============================================================================================================

local function LFGShoutFrame_OnEvent(self, event, ...)
	--print(event, time(), self:GetName(), ...)
	if event == "ADDON_LOADED" then
		if select(1, ...) == addonName then
			LFGShout_Load()
			LFGShout_RefreshChannels()
			self:UnregisterEvent("ADDON_LOADED")
			LFGShoutFrame:GetScript("OnMouseUp")(LFGShoutFrame, RIGHT_BUTTON)
--			LFGShoutFrame.OptionsButton:GetScript("OnMouseUp")(LFGShoutFrame.OptionsButton)
		end
	end

	if event == "CHANNEL_UI_UPDATE" or event == "ZONE_CHANGED_NEW_AREA" then
		C_Timer.After(1, LFGShout_RefreshChannels)
	end

end

-- =============================================================================================================

local function LFGShout_UnitPopup_ShowMenu(dropdownMenu, which, unit, name, userData)
	--print(dropdownMenu, which, unit, name, userData)
	--zd(dropdownMenu)
	--alerttable(dropdownMenu)
	--print(dropdownMenu:GetName())

	if string.find("SELF FRIEND BN_FRIEND PARTY GUILD PLAYER TARGET FOCUS RAID_PLAYER COMMUNITIES_GUILD_MEMBER COMMUNITIES_WOW_MEMBER COMMUNITIES_MEMBER COMMUNITIES_COMMUNITY", dropdownMenu.which) then
	--		and (dropdownMenu.owner == nil) 
	--		if UIDROPDOWNMENU_MENU_LEVEL == 1 then

		UIDropDownMenu_AddSeparator();

		local info = UIDropDownMenu_CreateInfo()

		local text = ""
		
		table.foreach(LFGShout_Settings.CheckedDungeons, 
			function(i, id)
				text = format("%s / %s", text, DUNGEON_LIST[id].Code)
			end
		)

		info.func = function(self, name, role) SendChatMessage(format("Hi there :)  Wanne %s %s ? %s", role, strtrim(text, " / "), LFGShoutFrame.OptionsFrame.EndText:GetText()), "WHISPER", nil, name) end
		info.owner = dropdownMenu
		info.arg1 = dropdownMenu.name
		info.notCheckable = true
		info.justifyH = "LEFT"
		
		local BUTTON_INFO = { "come", "Tank", "Heal", "DPS" }

		table.foreach(BUTTON_INFO, 
			function(k, role)
				info.arg2 = role
				info.text = format("|c00FF5C1ALFGShout|r <%s>", role)
				UIDropDownMenu_AddButton(info, 1)
			end
		)
		
	end
end

-- =============================================================================================================

local function LFGShout_Init()
	DEFAULT_CHAT_FRAME:AddMessage(format("[%s] Version: %s Loaded", addonName, VERSION), 1, .48, 0)
	LFGShoutFrame:SetScript("OnEvent", LFGShoutFrame_OnEvent)
	LFGShoutFrame:RegisterEvent("ADDON_LOADED")
	LFGShoutFrame:RegisterEvent("CHANNEL_UI_UPDATE")
	LFGShoutFrame:RegisterEvent("ZONE_CHANGED_NEW_AREA")
	--LFGShoutFrame:RegisterAllEvents()
	hooksecurefunc("UnitPopup_ShowMenu", LFGShout_UnitPopup_ShowMenu)
end

-- =============================================================================================================

LFGShout_Init()

-- =============================================================================================================
